==> haskell-hslua-module-zip-1.1.1-31-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-zip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-module-zip
version:              1.1.1
visibility:           public
id:                   hslua-module-zip-1.1.1-AWVJqM5dvJuIpHLIGJPyCj
key:                  hslua-module-zip-1.1.1-AWVJqM5dvJuIpHLIGJPyCj
license:              MIT
copyright:            © 2020-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with file zips.
description:
    Module with function for creating, modifying, and
    extracting files from zip archives.

category:             Foreign
abi:                  789ba1291d635ddb4ed4d200bb94d005
exposed:              True
exposed-modules:      HsLua.Module.Zip
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-module-zip-1.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-module-zip-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-zip
hs-libraries:         HShslua-module-zip-1.1.1-AWVJqM5dvJuIpHLIGJPyCj
depends:
    base-4.16.4.0 bytestring-0.11.4.0 filepath-1.4.2.2
    hslua-core-2.3.1-G0p4pDEAuRC9egDZNBd3TZ
    hslua-list-1.1.1-DXn51ZYv5PX9TDOE9EnuBt
    hslua-marshalling-2.3.1-1VequITq5GO81sRAuF35hQ
    hslua-packaging-2.3.1-gfdCfMkm5EGyR86RUIiCQ
    hslua-typing-0.1.1-7KGZWtEAJbu9bL9lsLYKhm text-1.2.5.0
    time-1.11.1.1 zip-archive-0.4.3.2-HwWEjrkz81r11b4b54QEFv

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-zip/html/hslua-module-zip.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-zip/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-zip-1.1.1-32-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-zip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-module-zip
version:              1.1.1
visibility:           public
id:                   hslua-module-zip-1.1.1-2a6XZINhn9QIGNYH37XKgt
key:                  hslua-module-zip-1.1.1-2a6XZINhn9QIGNYH37XKgt
license:              MIT
copyright:            © 2020-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with file zips.
description:
    Module with function for creating, modifying, and
    extracting files from zip archives.

category:             Foreign
abi:                  301d0d01e9ae079cb0d0922dd78b9245
exposed:              True
exposed-modules:      HsLua.Module.Zip
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-module-zip-1.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-module-zip-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-zip
hs-libraries:         HShslua-module-zip-1.1.1-2a6XZINhn9QIGNYH37XKgt
depends:
    base-4.16.4.0 bytestring-0.11.4.0 filepath-1.4.2.2
    hslua-core-2.3.1-1bLwXxpG3y4x6P7QmoCw1
    hslua-list-1.1.1-oAG0l7v8rg84Rw4lctS4t
    hslua-marshalling-2.3.1-EugHDCOqHZqHeFQAh5G7I4
    hslua-packaging-2.3.1-CWRoaUxzdqII2MImvJ2wj2
    hslua-typing-0.1.1-K9ACm0NXSfX1JkasUC8sV3 text-1.2.5.0
    time-1.11.1.1 zip-archive-0.4.3.2-JK86bbLwQpY7Gr8uE8Vl9P

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-zip/html/hslua-module-zip.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-zip/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
